class Contact < ActiveRecord::Base
  include Localized
  inheritable
  timestamps
  
  field :first_name
  field :second_name
  field :email
  field :text, :text
  field :read, :boolean, :default => false
  
  scope :unread, where("read IS NOT true")
  
  def name
    [first_name, second_name].compact.join(" ")
  end
  
  def unread?
    !read?
  end
  
  field :agreed_to_privacy, :boolean, :default => false
  validates_acceptance_of :agreed_to_privacy, :on => :create, :accept => true, :allow_nil => false
  validates_presence_of   :locale, :email, :first_name

  before_validation do |contact|
    contact.locale = I18n.locale.to_s
  end
  
  after_create do |contact|
    ContactsMailer.confirmation(contact).deliver
    ContactsMailer.notify(contact).deliver   
  end
  
  def read!
    unless read?
      update_attributes!(:read => true)      
    end
  end
  
  def unread!
    unless unread?
      update_attributes!(:read => false)
    end
  end
  
end